Script

Struct Script 

pub struct Script { /* private fields */ }

Implementations

Source

impl Script

pub fn new(core: Option<&Core>, vssapi: VssApi, api: Api) -> Self

Creates a new script instance.

Panics

Panics if the script creation fails.

pub fn get_api(&self) -> Api

pub fn core(&self) -> Result<CoreRef<'_>, ScriptError>

Returns a reference to the core associated with this script.

Errors

Returns an error message if the core could not be retrieved.

pub fn evaluate( &self, buffer: &CStr, filename: &CStr, ) -> Result<(), ScriptError>

Evaluates a script buffer with the given filename.

Errors

Returns an error message if the script evaluation fails.

pub fn evaluate_file(&self, filename: &CStr) -> Result<(), ScriptError>

Evaluates a script from a file.

Errors

Returns an error message if the script evaluation fails.

pub fn get_output(&self, index: c_int) -> Result<OutputNode, ScriptError>

Gets the output node at the specified index.

Errors

Returns a ScriptError if the output node could not be retrieved.